@@ -1,15 +1,19 @@
 from inspect import isclass
 from typing import Any, Dict, Type, cast
 
-from pydantic import BaseModel, create_model
+from pydantic import BaseConfig, BaseModel, create_model
 from pydantic.fields import ModelField
 from pydantic_factories.utils import create_model_from_dataclass
 
 
+class Config(BaseConfig):
+    arbitrary_types_allowed = True
+
+
 def create_parsed_model_field(value: Type[Any]) -> ModelField:
     """Create a pydantic model with the passed in value as its sole field, and return the parsed field"""
 
-    model = create_model("temp", **{"value": (value, ... if not repr(value).startswith("typing.Optional") else None)})  # type: ignore
+    model = create_model("temp", __config__=Config, **{"value": (value, ... if not repr(value).startswith("typing.Optional") else None)})  # type: ignore
     return cast(BaseModel, model).__fields__["value"]
 
 
